      SUBROUTINE SNOWPACK ( W,DTS,HC,DS,TSNOW,TSOIL )

      IMPLICIT NONE

C ##############################################################
C ##  SUBROUTINE TO CALCULATE COMPACTION OF SNOWPACK  UNDER  ###
C ##  CONDITIONS OF INCREASING SNOW DENSITY, AS OBTAINED     ###
C FROM AN APPROXIMATE SOLUTION OF E. ANDERSON'S DIFFERENTIAL ###
C     EQUATION (3.29), NOAA TECHNICAL REPORT NWS 19,         ###
C                 BY   VICTOR KOREN   03/25/95               ###
C ##############################################################

C ##############################################################
C  W      IS A WATER EQUIVALENT OF SNOW, IN M                ###
C  DTS    IS A TIME STEP, IN SEC                             ###
C  HC     IS A SNOW DEPTH, IN M                              ###
C  DS     IS A SNOW DENSITY, IN G/CM3                        ###
C  TSNOW  IS A SNOW SURFACE TEMPERATURE, K                   ###
C  TSOIL  IS A SOIL SURFACE TEMPERATURE, K                   ###
C      SUBROUTINE WILL RETURN NEW VALUES OF H AND DS         ###
C ##############################################################

      INTEGER IPOL
      INTEGER J

      REAL C1, C2, HC, W, DTS, DS, TSNOW, TSOIL, H, WX
      REAL DT, TSNOWX, TSOILX, TAVG, B, DSX, DW
      REAL PEXP

      PARAMETER (C1=0.01, C2=21.0)

C ##  CONVERSION INTO SIMULATION UNITS   ######################### 

      H=HC*100.
      WX=W*100.
      DT=DTS/3600.
      TSNOWX=TSNOW-273.15
      TSOILX=TSOIL-273.15

C ##  CALCULATING OF AVERAGE TEMPERATURE OF SNOW PACK              ###

      TAVG=0.5*(TSNOWX+TSOILX)                                    

C ##  CALCULATING OF SNOW DEPTH AND DENSITY AS A RESULT OF COMPACTION
C              DS=DS0*(EXP(B*W)-1.)/(B*W)
C              B=DT*C1*EXP(0.08*TAVG-C2*DS0)
C NOTE: B*W IN DS EQN ABOVE HAS TO BE CAREFULLY TREATED 
C NUMERICALLY BELOW
C ##  C1 IS THE FRACTIONAL INCREASE IN DENSITY (1/(CM*HR)) 
C ##  C2 IS A CONSTANT (CM3/G) KOJIMA ESTIMATED AS 21 CMS/G

      IF(WX .GT. 1.E-2) THEN
         B=DT*C1*EXP(0.08*TAVG-C2*DS)

C.........DSX=DS*((DEXP(B*WX)-1.)/(B*WX))
C--------------------------------------------------------------------
C  The function of the form (e**x-1)/x imbedded in above expression
C  for DSX was causing numerical difficulties when the denominator "x"
C  (i.e. B*WX) became zero or approached zero (despite the fact that
C  the analytical function (e**x-1)/x has a well defined limit as 
C  "x" approaches zero), hence below we replace the (e**x-1)/x 
C  expression with an equivalent, numerically well-behaved 
C  polynomial expansion.
C 
C  Number of terms of polynomial expansion, and hence its accuracy, 
C  is governed by iteration limit "ipol".
C       ipol greater than 9 only makes a difference on double
C             precision (relative errors given in percent %).
C        ipol=9, for rel.error <~ 1.6 e-6 % (8 significant digits)
C        ipol=8, for rel.error <~ 1.8 e-5 % (7 significant digits)
C        ipol=7, for rel.error <~ 1.8 e-4 % ...

        ipol = 4
        PEXP = 0.
        do j = ipol,1,-1
         PEXP = (1. + PEXP)*B*WX/real(j+1) 
        end do 
        PEXP = PEXP + 1.
C
        DSX=DS*(PEXP)
C                     above line ends polynomial substitution
         IF(DSX .GT. 0.40) DSX=0.40
         IF(DSX .LT. 0.05) DSX=DS
         DS=DSX
         H=WX/DS

C ##  UPDATE OF SNOW DEPTH AND DENSITY DEPENDING ON LIQUID WATER
C ##  DURING SNOWMELT. ASSUMED THAT 13% OF LIQUID WATER CAN BE STORED
C ##  IN SNOW PER DAY DURING SNOWMELT TILL SNOW DENSITY 0.40

         IF((TSNOWX .GE. 0.) .AND. (H .NE. 0.)) THEN
            DW=0.13*DT/24.
            DS=DS*(1.-DW)+DW
            IF(DS .GT. 0.40) DS=0.40
            H=WX/DS
         ENDIF
                   
      ELSE
         IF(WX .LE. 0.) THEN
            WX=0.
            H=0.
            DS=0.
         ELSE
            H=WX/DS
         ENDIF
 
      ENDIF

C ##  REPLACE PREVIOUS LIQUID WATER AND CHANGE DEPTH TO M

      HC=H*0.01

      RETURN
      END
